get_x_navigation_generator_interface library
Classes
- Marks a class as a navigator and create a base navigator class for it
- GetXRoute
- Marks a class as a get X route, a page and method will be generated
- GetXRouteConstructor
- The constructor or static method to use to create a get X route The arguments will be used to generate the goTo method
Enums
- The type of navigation to use
Constants
-
const instance of
InjectableInitwith default arguments - getXRoute → const GetXRoute
- const instance of GetXRoute with default arguments
- getXRouteConstructor → const GetXRouteConstructor
- const instance of GetXRouteConstructor